@@ -24,12 +24,285 @@ from ._jsii import *
 import ros_cdk_core as _ros_cdk_core_7adfd82f
 
 
+@jsii.interface(jsii_type="@alicloud/ros-cdk-paidswapi.IInstance")
+class IInstance(_ros_cdk_core_7adfd82f.IResource, typing_extensions.Protocol):
+    '''Represents a ``Instance``.'''
+
+    @builtins.property
+    @jsii.member(jsii_name="attrAccessibility")
+    def attr_accessibility(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute Accessibility: Whether the workspace is visible to others.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrDatasets")
+    def attr_datasets(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute Datasets: A collection of datasets.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrEcsSpec")
+    def attr_ecs_spec(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute EcsSpec: The ECS specification of the instance.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrEnvironmentVariables")
+    def attr_environment_variables(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute EnvironmentVariables: Environment variable.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrImageUrl")
+    def attr_image_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute ImageUrl: The mirror address.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrInstanceId")
+    def attr_instance_id(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute InstanceId: The first ID of the resource.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrInstanceName")
+    def attr_instance_name(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute InstanceName: The instance name.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrInstanceUrl")
+    def attr_instance_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute InstanceUrl: The instance address.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrJupyterlabUrl")
+    def attr_jupyterlab_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute JupyterlabUrl: The jupyterlab address.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrLabels")
+    def attr_labels(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute Labels: User-defined labels.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrPaymentType")
+    def attr_payment_type(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute PaymentType: The payment type of the resource.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrTerminalUrl")
+    def attr_terminal_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute TerminalUrl: The terminal address.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrUserVpc")
+    def attr_user_vpc(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute UserVpc: User vpc configuration.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrWebIdeUrl")
+    def attr_web_ide_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute WebIDEUrl: The web IDE address.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="attrWorkspaceId")
+    def attr_workspace_id(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute WorkspaceId: The Id of the workspace.'''
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="props")
+    def props(self) -> "InstanceProps":
+        ...
+
+
+class _IInstanceProxy(
+    jsii.proxy_for(_ros_cdk_core_7adfd82f.IResource), # type: ignore[misc]
+):
+    '''Represents a ``Instance``.'''
+
+    __jsii_type__: typing.ClassVar[str] = "@alicloud/ros-cdk-paidswapi.IInstance"
+
+    @builtins.property
+    @jsii.member(jsii_name="attrAccessibility")
+    def attr_accessibility(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute Accessibility: Whether the workspace is visible to others.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrAccessibility"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrDatasets")
+    def attr_datasets(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute Datasets: A collection of datasets.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrDatasets"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrEcsSpec")
+    def attr_ecs_spec(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute EcsSpec: The ECS specification of the instance.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrEcsSpec"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrEnvironmentVariables")
+    def attr_environment_variables(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute EnvironmentVariables: Environment variable.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrEnvironmentVariables"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrImageUrl")
+    def attr_image_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute ImageUrl: The mirror address.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrImageUrl"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrInstanceId")
+    def attr_instance_id(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute InstanceId: The first ID of the resource.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrInstanceId"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrInstanceName")
+    def attr_instance_name(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute InstanceName: The instance name.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrInstanceName"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrInstanceUrl")
+    def attr_instance_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute InstanceUrl: The instance address.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrInstanceUrl"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrJupyterlabUrl")
+    def attr_jupyterlab_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute JupyterlabUrl: The jupyterlab address.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrJupyterlabUrl"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrLabels")
+    def attr_labels(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute Labels: User-defined labels.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrLabels"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrPaymentType")
+    def attr_payment_type(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute PaymentType: The payment type of the resource.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrPaymentType"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrTerminalUrl")
+    def attr_terminal_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute TerminalUrl: The terminal address.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrTerminalUrl"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrUserVpc")
+    def attr_user_vpc(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute UserVpc: User vpc configuration.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrUserVpc"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrWebIdeUrl")
+    def attr_web_ide_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute WebIDEUrl: The web IDE address.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrWebIdeUrl"))
+
+    @builtins.property
+    @jsii.member(jsii_name="attrWorkspaceId")
+    def attr_workspace_id(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
+        '''Attribute WorkspaceId: The Id of the workspace.'''
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrWorkspaceId"))
+
+    @builtins.property
+    @jsii.member(jsii_name="props")
+    def props(self) -> "InstanceProps":
+        return typing.cast("InstanceProps", jsii.get(self, "props"))
+
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IInstance).__jsii_proxy_class__ = lambda : _IInstanceProxy
+
+
+@jsii.implements(IInstance)
 class Instance(
     _ros_cdk_core_7adfd82f.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@alicloud/ros-cdk-paidswapi.Instance",
 ):
-    '''A ROS resource type:  ``ALIYUN::PaiDswApi::Instance``.'''
+    '''This class encapsulates and extends the ROS resource type ``ALIYUN::PaiDswApi::Instance``, which is used to create a Data Science Workshop (DSW) instance.
+
+    :Note:
+
+    This class may have some new functions to facilitate development, so it is recommended to use this class instead of ``RosInstance``for a more convenient development experience.
+    See https://www.alibabacloud.com/help/ros/developer-reference/aliyun-paidswapi-instance
+    '''
 
     def __init__(
         self,
@@ -38,11 +311,7 @@ class Instance(
         props: typing.Union["InstanceProps", typing.Dict[builtins.str, typing.Any]],
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
-        '''Create a new ``ALIYUN::PaiDswApi::Instance``.
-
-        Param scope - scope in which this resource is defined
-        Param id    - scoped id of the resource
-        Param props - resource properties
+        '''Param scope - scope in which this resource is defined Param id    - scoped id of the resource Param props - resource properties.
 
         :param scope: -
         :param id: -
@@ -59,93 +328,164 @@ class Instance(
 
     @builtins.property
     @jsii.member(jsii_name="attrAccessibility")
-    def attr_accessibility(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_accessibility(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute Accessibility: Whether the workspace is visible to others.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrAccessibility"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrAccessibility"))
 
     @builtins.property
     @jsii.member(jsii_name="attrDatasets")
-    def attr_datasets(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_datasets(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute Datasets: A collection of datasets.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrDatasets"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrDatasets"))
 
     @builtins.property
     @jsii.member(jsii_name="attrEcsSpec")
-    def attr_ecs_spec(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_ecs_spec(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute EcsSpec: The ECS specification of the instance.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrEcsSpec"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrEcsSpec"))
 
     @builtins.property
     @jsii.member(jsii_name="attrEnvironmentVariables")
-    def attr_environment_variables(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_environment_variables(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute EnvironmentVariables: Environment variable.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrEnvironmentVariables"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrEnvironmentVariables"))
 
     @builtins.property
     @jsii.member(jsii_name="attrImageUrl")
-    def attr_image_url(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_image_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute ImageUrl: The mirror address.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrImageUrl"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrImageUrl"))
 
     @builtins.property
     @jsii.member(jsii_name="attrInstanceId")
-    def attr_instance_id(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_instance_id(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute InstanceId: The first ID of the resource.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrInstanceId"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrInstanceId"))
 
     @builtins.property
     @jsii.member(jsii_name="attrInstanceName")
-    def attr_instance_name(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_instance_name(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute InstanceName: The instance name.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrInstanceName"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrInstanceName"))
 
     @builtins.property
     @jsii.member(jsii_name="attrInstanceUrl")
-    def attr_instance_url(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_instance_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute InstanceUrl: The instance address.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrInstanceUrl"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrInstanceUrl"))
 
     @builtins.property
     @jsii.member(jsii_name="attrJupyterlabUrl")
-    def attr_jupyterlab_url(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_jupyterlab_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute JupyterlabUrl: The jupyterlab address.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrJupyterlabUrl"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrJupyterlabUrl"))
 
     @builtins.property
     @jsii.member(jsii_name="attrLabels")
-    def attr_labels(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_labels(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute Labels: User-defined labels.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrLabels"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrLabels"))
 
     @builtins.property
     @jsii.member(jsii_name="attrPaymentType")
-    def attr_payment_type(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_payment_type(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute PaymentType: The payment type of the resource.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrPaymentType"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrPaymentType"))
 
     @builtins.property
     @jsii.member(jsii_name="attrTerminalUrl")
-    def attr_terminal_url(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_terminal_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute TerminalUrl: The terminal address.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrTerminalUrl"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrTerminalUrl"))
 
     @builtins.property
     @jsii.member(jsii_name="attrUserVpc")
-    def attr_user_vpc(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_user_vpc(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute UserVpc: User vpc configuration.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrUserVpc"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrUserVpc"))
 
     @builtins.property
     @jsii.member(jsii_name="attrWebIdeUrl")
-    def attr_web_ide_url(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_web_ide_url(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute WebIDEUrl: The web IDE address.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrWebIdeUrl"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrWebIdeUrl"))
 
     @builtins.property
     @jsii.member(jsii_name="attrWorkspaceId")
-    def attr_workspace_id(self) -> _ros_cdk_core_7adfd82f.IResolvable:
+    def attr_workspace_id(
+        self,
+    ) -> typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]:
         '''Attribute WorkspaceId: The Id of the workspace.'''
-        return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrWorkspaceId"))
+        return typing.cast(typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable], jsii.get(self, "attrWorkspaceId"))
+
+    @builtins.property
+    @jsii.member(jsii_name="props")
+    def props(self) -> "InstanceProps":
+        return typing.cast("InstanceProps", jsii.get(self, "props"))
+
+    @builtins.property
+    @jsii.member(jsii_name="enableResourcePropertyConstraint")
+    def _enable_resource_property_constraint(self) -> builtins.bool:
+        return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
+
+    @_enable_resource_property_constraint.setter
+    def _enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__70efdf4da4b2df29c61736fe871d93a143476104d28429697efab32fe29c7967)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "enableResourcePropertyConstraint", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="id")
+    def _id(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "id"))
+
+    @_id.setter
+    def _id(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__ef8a17f373291d0f56a95c126d3985ed30177dcf15f62a04b3b844e9509426f7)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "id", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="scope")
+    def _scope(self) -> _ros_cdk_core_7adfd82f.Construct:
+        return typing.cast(_ros_cdk_core_7adfd82f.Construct, jsii.get(self, "scope"))
+
+    @_scope.setter
+    def _scope(self, value: _ros_cdk_core_7adfd82f.Construct) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__79911711b69cdd45fa93f5b9c646a175a078bbe3ebfb3a76b054590b498a0146)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "scope", value)
 
 
 @jsii.data_type(
@@ -179,7 +519,9 @@ class InstanceProps:
         user_vpc: typing.Optional[typing.Union[_ros_cdk_core_7adfd82f.IResolvable, typing.Union["RosInstance.UserVpcProperty", typing.Dict[builtins.str, typing.Any]]]] = None,
         workspace_id: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     ) -> None:
-        '''Properties for defining a ``ALIYUN::PaiDswApi::Instance``.
+        '''Properties for defining a ``Instance``.
+
+        See https://www.alibabacloud.com/help/ros/developer-reference/aliyun-paidswapi-instance
 
         :param ecs_spec: Property ecsSpec: The ECS specification of the instance.
         :param image_url: Property imageUrl: The mirror address.
@@ -336,7 +678,13 @@ class RosInstance(
     metaclass=jsii.JSIIMeta,
     jsii_type="@alicloud/ros-cdk-paidswapi.RosInstance",
 ):
-    '''A ROS template type:  ``ALIYUN::PaiDswApi::Instance``.'''
+    '''This class is a base encapsulation around the ROS resource type ``ALIYUN::PaiDswApi::Instance``, which is used to create a Data Science Workshop (DSW) instance.
+
+    :Note:
+
+    This class does not contain additional functions, so it is recommended to use the ``Instance`` class instead of this class for a more convenient development experience.
+    See https://www.alibabacloud.com/help/ros/developer-reference/aliyun-paidswapi-instance
+    '''
 
     def __init__(
         self,
@@ -345,8 +693,7 @@ class RosInstance(
         props: typing.Union["RosInstanceProps", typing.Dict[builtins.str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
-        '''Create a new ``ALIYUN::PaiDswApi::Instance``.
-
+        '''
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
         :param props: - resource properties.
@@ -929,7 +1276,9 @@ class RosInstanceProps:
         user_vpc: typing.Optional[typing.Union[_ros_cdk_core_7adfd82f.IResolvable, typing.Union[RosInstance.UserVpcProperty, typing.Dict[builtins.str, typing.Any]]]] = None,
         workspace_id: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     ) -> None:
-        '''Properties for defining a ``ALIYUN::PaiDswApi::Instance``.
+        '''Properties for defining a ``RosInstance``.
+
+        See https://www.alibabacloud.com/help/ros/developer-reference/aliyun-paidswapi-instance
 
         :param ecs_spec: 
         :param image_url: 
@@ -1100,14 +1449,19 @@ class RosInstanceProps:
 
 
 __all__ = [
+    "IInstance",
     "Instance",
     "InstanceProps",
     "RosInstance",
     "RosInstanceProps",
+    "datasource",
 ]
 
 publication.publish()
 
+# Loading modules to ensure their types are registered with the jsii runtime library
+from . import datasource
+
 def _typecheckingstub__108f944ad55884959cb52652dd6c2f7528e01478e209f9b59e8006920bfa877b(
     scope: _ros_cdk_core_7adfd82f.Construct,
     id: builtins.str,
@@ -1117,6 +1471,24 @@ def _typecheckingstub__108f944ad55884959cb52652dd6c2f7528e01478e209f9b59e8006920
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__70efdf4da4b2df29c61736fe871d93a143476104d28429697efab32fe29c7967(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ef8a17f373291d0f56a95c126d3985ed30177dcf15f62a04b3b844e9509426f7(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__79911711b69cdd45fa93f5b9c646a175a078bbe3ebfb3a76b054590b498a0146(
+    value: _ros_cdk_core_7adfd82f.Construct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__4fe690ddde5f352035475cdbeece49e469aeddc328c52c942fbefbe6e7b478d7(
     *,
     ecs_spec: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
